@@ -12,6 +12,7 @@
 #' @param coeff.inv a logical value of the coefficient invariance assumption across groups (random intercept model).
 #' @param init.param A set of model parameters to be used as the user-defined initial values for the EM algorithm. It should be \code{list} with the named parameters and have same structure of \code{param} of the \code{glca} output. In default, initial parameters are randomly generated.
 #' @param n.init number of randomly generated initial parameter sets to be used for avoiding the problem of local maxima.
+#' @param decreasing a logical value for whether reordering the parameters by descending order responding probability for first-category of first manifest item.
 #' @param testiter number of iterations in the EM algorithm for each initial parameter set. The initial parameter set that provides the largest log-likelihood will be selected for estimating the model.
 #' @param maxiter maximum number of iterations for the EM algorithm.
 #' @param eps a convergence tolerance value. When the largest absolute difference between former estimates and current estimates is less than \code{eps}, the algorithm will stop updating and consider the convergence to be reached.
@@ -62,24 +63,24 @@
 #' data("gss08")
 #' # LCA
 #' lca = glca(item(DEFECT, HLTH, RAPE, POOR, SINGLE, NOMORE) ~ 1,
-#'             data = gss08, nclass = 3)
+#'             data = gss08, nclass = 3, n.init = 1)
 #' summary(lca)
 #'
 #' # LCA with covariate(s)
 #' lcr = glca(item(DEFECT, HLTH, RAPE, POOR, SINGLE, NOMORE) ~ AGE,
-#'            data = gss08, nclass = 3)
+#'            data = gss08, nclass = 3, n.init = 1)
 #' summary(lcr)
 #' coef(lcr)
 #'
+#'
 #' # Multiple-group LCA (MGLCA)
 #' mglca = glca(item(DEFECT, HLTH, RAPE, POOR, SINGLE, NOMORE) ~ 1,
-#'              group = DEGREE, data = gss08, nclass = 3)
+#'              group = DEGREE, data = gss08, nclass = 3, n.init = 1)
 #' summary(mglca)
 #'
-#'
 #' # Multiple-group LCA with covariate(s) (MGLCR)
 #' mglcr = glca(item(DEFECT, HLTH, RAPE, POOR, SINGLE, NOMORE) ~ SEX,
-#'              group = DEGREE, data = gss08, nclass = 3)
+#'              group = DEGREE, data = gss08, nclass = 3, n.init = 1)
 #' summary(mglcr)
 #' coef(mglcr)
 #'
@@ -90,13 +91,13 @@
 #' data("nyts18")
 #' # Multilevel LCA (MLCA)
 #' mlca = glca(item(ECIGT, ECIGAR, ESLT, EELCIGT, EHOOKAH) ~ 1,
-#'             group = SCH_ID, data = nyts18, nclass = 3, ncluster = 2)
+#'             group = SCH_ID, data = nyts18, nclass = 3, ncluster = 2, n.init = 1)
 #' summary(mlca)
 #'
 #' # MLCA with covariate(s) (MLCR)
 #' # (SEX: level-1 covariate, SCH_LEV: level-2 covariate)
 #' mlcr = glca(item(ECIGT, ECIGAR, ESLT, EELCIGT, EHOOKAH) ~ SEX + SCH_LEV,
-#'             group = SCH_ID, data = nyts18, nclass = 3, ncluster = 2)
+#'             group = SCH_ID, data = nyts18, nclass = 3, ncluster = 2, n.init = 1)
 #' coef(mlcr)
 #' }
 #'
@@ -104,8 +105,8 @@
 
 glca <- function(
    formula, group = NULL, data = NULL, nclass = 3, ncluster = NULL, std.err = TRUE,
-   measure.inv = TRUE, coeff.inv = TRUE, init.param = NULL, n.init = 10, testiter = 50,
-   maxiter = 5000, eps = 1e-6, na.rm = FALSE, seed = NULL, verbose = TRUE
+   measure.inv = TRUE, coeff.inv = TRUE, init.param = NULL, n.init = 10, decreasing = FALSE,
+   testiter = 50, maxiter = 5000, eps = 1e-6, na.rm = FALSE, seed = NULL, verbose = TRUE
 )
 {
    # Function call
@@ -164,6 +165,7 @@ glca <- function(
    # (model, x, y, group, z, param, posterior, gof, iter)
    ret = glca_output(call, terms, model, datalist, vname, EM, scores)
    class(ret) = "glca"
+   if (decreasing) ret = reorder(ret, decreasing = TRUE)
 
    return(ret)
 }
